==> css-render-0.13.0.tgz: package/esm/mount.js <==
import hash from './hash';
import { createElement, queryElement, removeElement } from './utils';
function getCount(el) {
    const count = el.getAttribute('mount-count');
    if (count === null)
        return null;
    return Number(count);
}
function setCount(el, count) {
    el.setAttribute('mount-count', String(count));
}
export { getCount, setCount };
export function unmount(intance, node, id, count) {
    const { els } = node;
    // If target is undefined, unmount all styles
    if (id === undefined) {
        els.forEach(removeElement);
        node.els = [];
    }
    else {
        const target = queryElement(id);
        // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
        if (target && els.includes(target)) {
            const mountCount = getCount(target);
            if (!count) {
                if (mountCount !== null) {
                    console.error(`[css-render/unmount]: The style with target='${id}' is mounted in no-count mode.`);
                }
                else {
                    removeElement(target);
                    node.els = els.filter(el => el !== target);
                }
            }
            else {
                if (mountCount === null) {
                    console.error(`[css-render/unmount]: The style with target='${id}' is mounted in count mode.`);
                }
                else {
                    if (mountCount <= 1) {
                        removeElement(target);
                        node.els = els.filter(el => el !== target);
                    }
                    else
                        setCount(target, mountCount - 1);
                }
            }
        }
    }
}
function addElementToList(els, target) {
    els.push(target);
}
function mount(instance, node, id, props, count, ssrAdapter) {
    let target;
    const { els } = node;
    let style;
    if (id === undefined) {
        style = node.render(props);
        id = hash(style);
    }
    if (ssrAdapter !== undefined) {
        ssrAdapter(id, style !== null && style !== void 0 ? style : node.render(props));
        // @ts-ignore
        return;
    }
    const queriedTarget = queryElement(id);
    if (queriedTarget === null) {
        target = createElement(id);
        if (style === undefined)
            style = node.render(props);
        target.textContent = style;
        document.head.appendChild(target);
        if (count) {
            setCount(target, 1);
        }
        addElementToList(els, target);
    }
    else {
        const mountCount = getCount(queriedTarget);
        if (count) {
            if (mountCount === null) {
                console.error(`[css-render/mount]: The style with id='${id}' has been mounted in no-count mode.`);
            }
            else {
                setCount(queriedTarget, mountCount + 1);
            }
        }
        else {
            if (mountCount !== null) {
                console.error(`[css-render/mount]: The style with id='${id}' has been mounted in count mode.`);
            }
        }
    }
    // @ts-ignore
    return queriedTarget !== null && queriedTarget !== void 0 ? queriedTarget : target;
}
export { mount };

==> css-render-0.13.3.tgz: package/esm/mount.js <==
import hash from './hash';
import { createElement, queryElement, removeElement } from './utils';
function getCount(el) {
    const count = el.getAttribute('mount-count');
    if (count === null)
        return null;
    return Number(count);
}
function setCount(el, count) {
    el.setAttribute('mount-count', String(count));
}
export { getCount, setCount };
export function unmount(intance, node, id, count) {
    const { els } = node;
    // If target is undefined, unmount all styles
    if (id === undefined) {
        els.forEach(removeElement);
        node.els = [];
    }
    else {
        const target = queryElement(id);
        // eslint-disable-next-line @typescript-eslint/strict-boolean-expressions
        if (target && els.includes(target)) {
            const mountCount = getCount(target);
            if (!count) {
                if (mountCount !== null) {
                    console.error(`[css-render/unmount]: The style with target='${id}' is mounted in no-count mode.`);
                }
                else {
                    removeElement(target);
                    node.els = els.filter(el => el !== target);
                }
            }
            else {
                if (mountCount === null) {
                    console.error(`[css-render/unmount]: The style with target='${id}' is mounted in count mode.`);
                }
                else {
                    if (mountCount <= 1) {
                        removeElement(target);
                        node.els = els.filter(el => el !== target);
                    }
                    else
                        setCount(target, mountCount - 1);
                }
            }
        }
    }
}
function addElementToList(els, target) {
    els.push(target);
}
function mount(instance, node, id, props, count, ssrAdapter
// eslint-disable-next-line @typescript-eslint/no-invalid-void-type
) {
    let target;
    const { els } = node;
    let style;
    if (id === undefined) {
        style = node.render(props);
        id = hash(style);
    }
    if (ssrAdapter !== undefined) {
        ssrAdapter(id, style !== null && style !== void 0 ? style : node.render(props));
        // @ts-expect-error
        return;
    }
    const queriedTarget = queryElement(id);
    if (queriedTarget === null) {
        target = createElement(id);
        if (style === undefined)
            style = node.render(props);
        target.textContent = style;
        document.head.appendChild(target);
        if (count) {
            setCount(target, 1);
        }
        addElementToList(els, target);
    }
    else {
        const mountCount = getCount(queriedTarget);
        if (count) {
            if (mountCount === null) {
                console.error(`[css-render/mount]: The style with id='${id}' has been mounted in no-count mode.`);
            }
            else {
                setCount(queriedTarget, mountCount + 1);
            }
        }
        else {
            if (mountCount !== null) {
                console.error(`[css-render/mount]: The style with id='${id}' has been mounted in count mode.`);
            }
        }
    }
    // @ts-expect-error
    return queriedTarget !== null && queriedTarget !== void 0 ? queriedTarget : target;
}
export { mount };
